<?php

namespace Drupal\acquia_contenthub\Form;

use Drupal\acquia_contenthub\ContentHubConnectionManager;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ContentHubDeleteClientConfirmForm.
 *
 * Defines a confirmation form to confirm deletion of Acquia Content Hub Client.
 *
 * @package Drupal\acquia_contenthub\Form
 */
class ContentHubDeleteClientConfirmForm extends ConfirmFormBase {

  /**
   * The Content Hub connection manager.
   *
   * @var \Drupal\acquia_contenthub\ContentHubConnectionManager
   */
  protected $chConnectionManager;

  /**
   * ContentHubDeleteClientConfirmForm constructor.
   *
   * @param \Drupal\acquia_contenthub\ContentHubConnectionManager $ch_connection_manager
   *   The Content Hub connection manager service.
   */
  public function __construct(ContentHubConnectionManager $ch_connection_manager) {
    $this->chConnectionManager = $ch_connection_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('acquia_contenthub.connection_manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $client_name = $this->config('acquia_contenthub.admin_settings')
      ->get('client_name');
    try {
      $this->chConnectionManager->unregister();
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t('Error during unregistration: @error_message', ['@error_message' => $e->getMessage()]));
      return;
    }

    $this->messenger()->addMessage($this->t('Successfully disconnected site %site from Content Hub.', ['%site' => $client_name]));

    $form_state->setRedirect('acquia_contenthub.admin_settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return "contenthub_delete_client_confirmation";
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('acquia_contenthub.admin_settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This action will delete the registration of this client with the Content Hub Service as well as the webhook attached to it. @blank
    If this site is a publisher, it will leave orphan published content in the service. Make sure to delete this content before proceeding with the unregistration. @blank
    This action cannot be undone. Are you sure you want to proceed?', [
      '@blank' => new FormattableMarkup('<br>', []),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {}

}
