<?php

namespace Drupal\Tests\acquia_contenthub\Kernel;

/**
 * Tests publisher tracker methods.
 *
 * @group acquia_contenthub
 *
 * @coversDefaultClass \Drupal\acquia_contenthub_publisher\PublisherTracker
 *
 * @requires module depcalc
 *
 * @package Drupal\Tests\acquia_contenthub\Kernel
 */
class PublisherTrackerTest extends NullifyQueueIdTest {

  /**
   * Test cases to tamper with CDF data before its imported.
   *
   * @covers ::listTrackedEntities
   *
   * @throws \Exception
   */
  public function testListTrackedEntities(): void {
    $list_tracked_entities_before = $this->publisherTracker->listTrackedEntities('queued', 'node');
    $this->assertEmpty($list_tracked_entities_before);

    // Create test node.
    $this->createNode();

    $list_tracked_entities_after = $this->publisherTracker->listTrackedEntities('queued', 'node');
    $this->assertNotEmpty($list_tracked_entities_after);
  }

  /**
   * Test cases to nullifies hashes.
   *
   * @covers ::nullifyHashes
   *
   * @throws \Exception
   */
  public function testNullifyHashes(): void {
    // Creates sample node type.
    $this->createNodeType('article', 'Article');

    // Create test node.
    $node = $this->createNode();

    while ($item = $this->queue->claimItem()) {
      $this->queueWorker->processItem($item->data);
    }

    $hash_before = $this->getTrackedEntityHash($node->id(), 'exported');
    $this->assertNotEmpty($hash_before[0]);

    $this->publisherTracker->nullifyHashes();
    $hash_after = $this->getTrackedEntityHash($node->id(), 'exported');
    $this->assertEmpty($hash_after[0]);
  }

  /**
   * Fetch entity "hash".
   *
   * @param string $entity_id
   *   Entity Id.
   * @param string $status
   *   Status of the entity.
   *
   * @return array
   *   The entity hash.
   */
  protected function getTrackedEntityHash(string $entity_id, string $status): array {
    $query = \Drupal::database()->select(self::TABLE_NAME, 't');
    $query->fields('t', ['hash']);
    $query->condition('entity_id', $entity_id);
    $query->condition('status', $status);

    return $query->execute()->fetchCol();
  }

}
